==> prismic-0.3.1.tar.gz: prismic-0.3.1/prismic/cache.py <==
# -*- coding: utf-8 -*-

import os
import shelve
from datetime import datetime


class NoCache(object):
    """
    A simple noop implementation for the cache. Any object implementing the same methods
    (duck typing) is acceptable as a cache backend.

    For example, python-memcached is compatible.
    """
    pass

    def set(self, key, val, time=0):
        pass

    def get(self, key):
        return None


class ShelveCache(object):
    """
    A cache implementation based on Shelve: https://docs.python.org/2/library/shelve.html.
    """
    def __init__(self):
        self.db = None

    def _init_db(self):
        if self.db is None:
            script_dir = os.path.dirname(os.path.realpath(__file__))
            self.db = shelve.open(os.path.join(script_dir, "cache"))

    def set(self, key, val, time=0):
        self._init_db()
        if type(key) != str:
            key = key.encode('utf8')
        self.db[key] = {
            "val": val,
            "expire": ShelveCache.unix_time() + time
        }

    def get(self, key):
        self._init_db()
        if type(key) != str:
            key = key.encode('utf8')
        if not key in self.db:
            return None
        d = self.db[key]
        if d["expire"] < ShelveCache.unix_time():
            del self.db[key]
            return None
        else:
            return d["val"]

    @staticmethod
    def unix_time():
        epoch = datetime.utcfromtimestamp(0)
        delta = datetime.now() - epoch
        return delta.total_seconds()

==> prismic-1.0.3.tar.gz: prismic-1.0.3/prismic/cache.py <==
# -*- coding: utf-8 -*-

import os
import tempfile
import shelve
from datetime import datetime


class NoCache(object):
    """
    A simple noop implementation for the cache. Any object implementing the same methods
    (duck typing) is acceptable as a cache backend.

    For example, python-memcached is compatible.
    """
    pass

    def set(self, key, val, time=0):
        pass

    def get(self, key):
        return None


class ShelveCache(object):
    """
    A cache implementation based on Shelve: https://docs.python.org/2/library/shelve.html.

    By default, it will be created with "filename" equal to the api domain name. If you want to
    run 2 processes using the same
    """
    def __init__(self, filename):
        self.filename = filename
        self.db = None

    def _init_db(self):
        if self.db is None:
            cache_dir = os.path.join(tempfile.gettempdir(), "prismic-cache")
            if not os.path.exists(cache_dir):
                os.makedirs(cache_dir)
            self.db = shelve.open(os.path.join(cache_dir, self.filename))

    def set(self, key, val, time=0):
        self._init_db()
        if type(key) != str:
            key = key.encode('utf8')
        self.db[key] = {
            "val": val,
            "expire": ShelveCache.unix_time() + time
        }

    def get(self, key):
        self._init_db()
        if type(key) != str:
            key = key.encode('utf8')
        if not key in self.db:
            return None
        d = self.db[key]
        if d["expire"] < ShelveCache.unix_time():
            del self.db[key]
            return None
        else:
            return d["val"]

    @staticmethod
    def unix_time():
        epoch = datetime.utcfromtimestamp(0)
        delta = datetime.now() - epoch
        return delta.total_seconds()
